==> haskell-blaze-markup-0.7.0.3-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-markup/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.0.3
id: blaze-markup-0.7.0.3-adfaa12a6c8f95338d1eda4a379eb541
key: blaze_KHuH8QXnlq29LQ51QRCHo0
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-markup-0.7.0.3
hs-libraries: HSblaze-markup-0.7.0.3-KHuH8QXnlq29LQ51QRCHo0
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.7.0.3-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-markup/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.0.3
id: blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
key: blaze_0GHhaMWFHoQLer0aTKr3fi
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-markup-0.7.0.3
hs-libraries: HSblaze-markup-0.7.0.3-0GHhaMWFHoQLer0aTKr3fi
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
